| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Tokstyle.Analysis.AccessPath
Synopsis
- data AccessPath
- isPathPrefixOf :: AccessPath -> AccessPath -> Bool
- pathDepth :: AccessPath -> Int
Documentation
data AccessPath Source #
Access path to a variable or part of it.
Constructors
| PathVar String | |
| PathParam Int | |
| PathReturn | |
| PathDeref AccessPath | |
| PathField AccessPath String | |
| PathIndex AccessPath String |
Instances
| Eq AccessPath Source # | |
Defined in Tokstyle.Analysis.AccessPath | |
| Ord AccessPath Source # | |
Defined in Tokstyle.Analysis.AccessPath Methods compare :: AccessPath -> AccessPath -> Ordering # (<) :: AccessPath -> AccessPath -> Bool # (<=) :: AccessPath -> AccessPath -> Bool # (>) :: AccessPath -> AccessPath -> Bool # (>=) :: AccessPath -> AccessPath -> Bool # max :: AccessPath -> AccessPath -> AccessPath # min :: AccessPath -> AccessPath -> AccessPath # | |
| Show AccessPath Source # | |
Defined in Tokstyle.Analysis.AccessPath Methods showsPrec :: Int -> AccessPath -> ShowS # show :: AccessPath -> String # showList :: [AccessPath] -> ShowS # | |
| Pretty AccessPath Source # | |
Defined in Tokstyle.Analysis.AccessPath | |
isPathPrefixOf :: AccessPath -> AccessPath -> Bool Source #
Check if the first path is a prefix of (or equal to) the second. e.g. "p" is a prefix of "p->f".
pathDepth :: AccessPath -> Int Source #