tokstyle-0.0.9: TokTok C code style checker
Safe HaskellNone
LanguageHaskell2010

Tokstyle.C.ObjectSystem

Synopsis

Documentation

data ObjectInfo Source #

Metadata for a struct that contains callbacks.

Constructors

ObjectInfo 

Instances

Instances details
Eq ObjectInfo Source # 
Instance details

Defined in Tokstyle.C.ObjectSystem

Show ObjectInfo Source # 
Instance details

Defined in Tokstyle.C.ObjectSystem

data CallbackSlot Source #

Represents a specific location where a callback can be stored.

Constructors

CallbackSlot 

discoverObjectTypes :: GlobalDecls -> Map String ObjectInfo Source #

Identify all structs that contain function pointers.

isFuncPtr :: Type -> Bool Source #

Check if a type is a function pointer or an array of them.